[−][src]Struct mdbook::config::HtmlConfig
Configuration for the HTML renderer.
Fields
theme: Option<PathBuf>The theme directory, if specified.
default_theme: Option<String>The default theme to use, defaults to 'light'
preferred_dark_theme: Option<String>The theme to use if the browser requests the dark version of the site. Defaults to the same as 'default_theme'
curly_quotes: boolUse "smart quotes" instead of the usual " character.
mathjax_support: boolShould mathjax be enabled?
google_analytics: Option<String>An optional google analytics code.
additional_css: Vec<PathBuf>Additional CSS stylesheets to include in the rendered page's <head>.
additional_js: Vec<PathBuf>Additional JS scripts to include at the bottom of the rendered page's
<body>.
fold: FoldFold settings.
playpen: PlaypenPlaypen settings.
no_section_label: boolDon't render section labels.
search: Option<Search>Search settings. If None, the default will be used.
git_repository_url: Option<String>Git repository url. If None, the git button will not be shown.
git_repository_icon: Option<String>FontAwesome icon class to use for the Git repository link.
Defaults to fa-github if None.
Methods
impl HtmlConfig[src]
pub fn theme_dir(&self, root: &PathBuf) -> PathBuf[src]
Returns the directory of theme from the provided root directory. If the directory is not present it will append the default directory of "theme"